# Convomeld

Tools for composing, validating, merging and simplifying the graph data structures that define the a conversational agent's behavior - a program that can be run by a conversation manager to interact with humans.

